@@ -351,14 +351,16 @@ def root_to_dataframe(
 
     dfs = []
     for tree_name in tree_names:
-        tree = root_file[tree_name]
         try:
+            tree = root_file[tree_name]
             dfs.append(tree.arrays(branches, library="pd"))  # type: ignore
         except uproot.exceptions.KeyInFileError as exc:  # type: ignore
             similar_keys = utils.find_similar_strings(exc.key, list(aliases), 0.80)
-            similar_keys += utils.find_similar_strings(exc.key, tree.keys(), 0.80)
             similar_keys += utils.find_similar_strings(
-                "probe_" + exc.key, tree.keys(), 0.80
+                exc.key, tree.keys(), 0.80  # type: ignore
+            )
+            similar_keys += utils.find_similar_strings(
+                "probe_" + exc.key, tree.keys(), 0.80  # type: ignore
             )
             # Remove duplicates while preserving ordering
             similar_keys = list(dict.fromkeys(similar_keys))
@@ -369,6 +371,18 @@ def root_to_dataframe(
                 )
             )
             raise
+        except OSError as err:
+            if "Operation expired" in err.args[0]:
+                log.error(
+                    (
+                        f"Failed to open '{path}' because an XRootD operation "
+                        "expired; skipping"
+                    )
+                )
+                print(err)
+                return None  # type: ignore
+            else:
+                raise
 
     return pd.concat(dfs, ignore_index=True)  # type: ignore
 
